@@ -15,7 +15,7 @@
 
 package Whisper;
 {
-  $Whisper::VERSION = '1.025';
+  $Whisper::VERSION = '1.026';
 }
 
 use strict;
@@ -388,8 +388,8 @@ Or in combination with date-format .e.g: "%Y/%m/%d %H:%M"
 
     {
         'step' => 300,
-        'end' => 1374830700,
-        'start' => 1374830100,
+        'end' => '2013/07/26 11:25',
+        'start' => '2013/07/26 11:15',
         'values' => [
             [ '2013/07/26 11:15', '0.000000' ],
             [ '2013/07/26 11:20', '1.000000' ]
